=======
Credits
=======

* João Molon <jtmolon@gmail.com>

Special thanks
--------------

To Zlatko Mašek <zlatko.masek@gmail.com>, `OffSetLab <https://www.offsetlab.net/>`_ for inspiring the writing of this package. `Shamrock <https://github.com/zmasek/shamrock>`_ was used as a template both for implementation as for structure of this package.
